#
# spec file for package perl-DBIx-Class
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name DBIx-Class
Name:           perl-DBIx-Class
Version:        0.082843
Release:        1.8
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Extensible and flexible object <-> relational mapper
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RI/RIBASUSHI/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Accessor::Grouped) >= 0.10012
BuildRequires:  perl(Class::C3::Componentised) >= 1.0009
BuildRequires:  perl(Class::Inspector) >= 1.24
BuildRequires:  perl(Config::Any) >= 0.20
BuildRequires:  perl(Context::Preserve) >= 0.01
BuildRequires:  perl(DBD::SQLite) >= 1.29
BuildRequires:  perl(DBI) >= 1.57
BuildRequires:  perl(Data::Dumper::Concise) >= 2.020
BuildRequires:  perl(Devel::GlobalDestruction) >= 0.09
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.59
BuildRequires:  perl(File::Temp) >= 0.22
BuildRequires:  perl(Hash::Merge) >= 0.12
BuildRequires:  perl(MRO::Compat) >= 0.12
BuildRequires:  perl(Module::Find) >= 0.07
BuildRequires:  perl(Moo) >= 2.000
BuildRequires:  perl(Package::Stash) >= 0.28
BuildRequires:  perl(Path::Class) >= 0.18
BuildRequires:  perl(SQL::Abstract::Classic) >= 1.91
BuildRequires:  perl(Scope::Guard) >= 0.03
BuildRequires:  perl(Sub::Name) >= 0.04
BuildRequires:  perl(Test::Deep) >= 0.101
BuildRequires:  perl(Test::Exception) >= 0.310000
BuildRequires:  perl(Test::More) >= 0.94
BuildRequires:  perl(Test::Warn) >= 0.21
BuildRequires:  perl(Text::Balanced) >= 2.00
BuildRequires:  perl(Try::Tiny) >= 0.07
BuildRequires:  perl(namespace::clean) >= 0.24
Requires:       perl(Class::Accessor::Grouped) >= 0.10012
Requires:       perl(Class::C3::Componentised) >= 1.0009
Requires:       perl(Class::Inspector) >= 1.24
Requires:       perl(Config::Any) >= 0.20
Requires:       perl(Context::Preserve) >= 0.01
Requires:       perl(DBI) >= 1.57
Requires:       perl(Data::Dumper::Concise) >= 2.020
Requires:       perl(Devel::GlobalDestruction) >= 0.09
Requires:       perl(Hash::Merge) >= 0.12
Requires:       perl(MRO::Compat) >= 0.12
Requires:       perl(Module::Find) >= 0.07
Requires:       perl(Moo) >= 2.000
Requires:       perl(Path::Class) >= 0.18
Requires:       perl(SQL::Abstract::Classic) >= 1.91
Requires:       perl(Scope::Guard) >= 0.03
Requires:       perl(Sub::Name) >= 0.04
Requires:       perl(Text::Balanced) >= 2.00
Requires:       perl(Try::Tiny) >= 0.07
Requires:       perl(namespace::clean) >= 0.24
%{perl_requires}
# MANUAL BEGIN
# workaround a spurious test failure in "skipped" t/cdbi/mk_group_accessors.t
BuildRequires:  perl(Class::DBI)
# MANUAL END

%description
This is an SQL to OO mapper with an object API inspired by Class::DBI (with
a compatibility layer as a springboard for porting) and a resultset API
that allows abstract encapsulation of database operations. It aims to make
representing queries in your code as perl-ish as possible while still
providing access to as many of the capabilities of the database as
possible, including retrieving related records from multiple tables in a
single query, 'JOIN', 'LEFT JOIN', 'COUNT', 'DISTINCT', 'GROUP BY', 'ORDER
BY' and 'HAVING' support.

DBIx::Class can handle multi-column primary and foreign keys, complex
queries and database-level paging, and does its best to only query the
database in order to return something you've directly asked for. If a
resultset is used as an iterator it only fetches rows off the statement
handle as requested in order to minimise memory usage. It has
auto-increment support for SQLite, MySQL, PostgreSQL, Oracle, SQL Server
and DB2 and is known to be used in production on at least the first four,
and is fork- and thread-safe out of the box (although your DBD may not be).

This project is still under rapid development, so large new features may be
marked *experimental* - such APIs are still usable but may have edge bugs.
Failing test cases are _always_ welcome and point releases are put out
rapidly as bugs are found and fixed.

We do our best to maintain full backwards compatibility for published APIs,
since DBIx::Class is used in production in many organisations, and even
backwards incompatible changes to non-published APIs will be fixed if
they're reported and doing so doesn't cost the codebase anything.

The test suite is quite substantial, and several developer releases are
generally made to CPAN before the branch for the next release is merged
back to trunk for a major release.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
sed -i -e 's/use inc::Module::Install/use lib q[.];\nuse inc::Module::Install/' Makefile.PL
# MANUAL END

%build
PERL_USE_UNSAFE_INC=1 perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc AUTHORS Changes examples README
%license LICENSE

%changelog
* Wed May 18 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.082843
  see /usr/share/doc/packages/perl-DBIx-Class/Changes
  0.082843 2022-05-17 10:50 (UTC)
  * Fixes
  - Adjust tests to account for DBD::SQLite's column_info() no longer
    being case-preserving in recent versions
  - Fix t/storage/replicated.t relying on no-longer-available module
  - Adjust t/53lean_startup.t to work around spurious changes in
    Perl5 core (GH#143)
* Wed Jun 17 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.082842
  see /usr/share/doc/packages/perl-DBIx-Class/Changes
  0.082842 2020-06-16 20:10 (UTC)
  * New Features
  - An on_connect rebase_sqlmaker call allowing experimentation with
    non-core SQL generators on a per-$schema-instance basis
    https://is.gd/DBIC_rebase_sqlmaker
  - Automatically detect and use multi-column IN on recent versions of
    libsqlite: ... WHERE ( foo, bar ) IN ( SELECT foo, bar FROM ... )
  * Fixes
  - Fix silent failure to retrieve a primary key (RT#80283) or worse:
    returning an incorrect value (RT#115381) in case a rdbms-side autoinc
    column is declared as PK with the is_auto_increment attribute unset
  - Fix overly-aggressive condition unrolling, corrupting custom ops with
    array arguments (RT#132390)
  - Fix docs on how to properly use Moo(se) in ResultSet's, and fix a
    corner case of ->count not functioning properly when the old recipe
    was being used (GH#105)
  - Fix incorrect ::Storage->_ping() behavior under Sybase (RT#114214)
  - Work around breakage in Hash::Merge by soft-requiring Clone as part
    of the replicated subsystem (RT#124321)
  * Misc
  - DBIC_TRACE_PROFILE=... now uses a ::Storage::Statistics subclass
    DBIx::Class::Storage::Debug::PrettyTrace which properly ships as a
    part of this distrinbution
  - Switch out SQL::Abstract dependency with a slower moving dist
  - Remove Data::Page dependency by inlining its entirety into the core
    DBIx::Class::ResultSet::Pager (RT#130686)
* Wed Feb  7 2018 coolo@suse.com
- updated to 0.082841
  see /usr/share/doc/packages/perl-DBIx-Class/Changes
  0.082841 2018-01-29 08:10 (UTC)
  * Test-suite fixup changes only - no reason to upgrade, wait for 0.082850
  * Misc
  - Unblock DBD::SQLite (RT#118395)
  - Fix missing ORDER BY leading to failures of t/prefetch/grouped.t
    under upcoming libsqlite (RT#117271)
  - Temporarily disable a non-critical portion of test failing on
    upcoming libsqlite, proper fix coming in 0.082850 (RT#119845)
  - Add test workaround for ( largely irrelevant ) RT#120129
  - Add temporary test-workaround for a devrel of DBD::SQLite
    RT#124227 / https://twitter.com/dbix_class/status/957271153751527424
  - Add workaround for one of the most damaging "improvements" made
    during the modern-perl-era (RT#120827)
  - Fix malformed README file encoding (RT#122028)
* Wed Oct  4 2017 coolo@suse.com
- patch the Makefile to build with perl 5.26
* Thu Jun 23 2016 coolo@suse.com
- updated to 0.082840
  see /usr/share/doc/packages/perl-DBIx-Class/Changes
  0.082840 2016-06-20 07:02 (UTC)
  * New Features
  - When using non-scalars (e.g. arrays) as literal bind values it is no
    longer necessary to explicitly specify a bindtype (this turned out
    to be a mostly useless overprotection)
  * Fixes
  - Ensure leaving an exception stack via Return::MultiLevel or something
    similar produces a large warning
  - Another relatively invasive set of ::FilterColumn changes, covering
    potential data loss (RT#111567). Please run your regression tests!
  - Ensure failing on_connect* / on_disconnect* are dealt with properly,
    notably on_connect* failures now properly abort the entire connect
  - Fix use of ::Schema::Versioned combined with a user-supplied
    $dbh->{HandleError} (GH#101)
  - Fix parsing of DSNs containing driver arguments (GH#99)
  - Fix silencing of exceptions thrown by custom inflate_result() methods
  - Fix complex prefetch when ordering over foreign boolean columns
    ( Pg can't MAX(boolcol) despite being able to ORDER BY boolcol )
  - Fix infinite loop on ->svp_release("nonexistent_savepoint") (GH#97)
  - Fix spurious ROLLBACK statements when a TxnScopeGuard fails a commit
    of a transaction with deferred FK checks: a guard is now inactivated
    immediately before the commit is attempted (RT#107159)
  - Fix the Sybase ASE storage incorrectly attempting to retrieve an
    autoinc value when inserting rows containing blobs (GH#82)
  - Remove spurious exception warping in ::Replicated::execute_reliably
    (RT#113339)
  - Work around unreliable $sth->finish() on INSERT ... RETURNING within
    DBD::Firebird on some compiler/driver combinations (RT#110979)
  - Fix leaktest failures with upcoming version of Sub::Quote
  - Really fix savepoint rollbacks on older DBD::SQLite (fix in 0.082800
    was not sufficient to cover up RT#67843)
  * Misc
  - Test suite is now officially certified to work under very high random
    parallelism: META x_parallel_test_certified set to true accordingly
  - Typo fixes from downstream debian packagers (RT#112007)
* Sat Feb 13 2016 coolo@suse.com
- updated to 0.082821
  see /usr/share/doc/packages/perl-DBIx-Class/Changes
  0.082821 2016-02-11 17:58 (UTC)
  * Fixes
  - Fix t/52leaks.t failures on compilerless systems (RT#104429)
  - Fix t/storage/quote_names.t failures on systems with specified Oracle
    test credentials while missing the optional Math::Base36
  - Fix test failures when DBICTEST_SYBASE_DSN is set (unnoticed change
    in error message wording during 0.082800 and a bogus test)
  - Remove largely obsolete test of SQLite view deployment (RT#111916)
  * Misc
  - Work around rare test deadlock under heavy parallelism (RT#108390)
* Tue Oct  6 2015 bwiedemann@suse.com
- workaround a spurious openSUSE:Leap:42.1 test failure
  in "skipped" t/cdbi/mk_group_accessors.t
  with a BuildRequires:  perl(Class::DBI)
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.082820
  see /usr/share/doc/packages/perl-DBIx-Class/Changes
  0.082820 2015-03-20 20:35 (UTC)
  * Fixes
  - Protect destructors from rare but possible double execution, and
    loudly warn the user whenever the problem is encountered (GH#63)
  - Relax the 'self_result_object' argument check in the relationship
    resolution codepath, restoring exotic uses of inflate_result
    http://lists.scsys.co.uk/pipermail/dbix-class/2015-January/011876.html
  - Fix updating multiple CLOB/BLOB columns on Oracle
  - Fix exception on complex update/delete under a replicated setup
    http://lists.scsys.co.uk/pipermail/dbix-class/2015-January/011903.html
  - Fix uninitialized warnings on empty hashes passed to join/prefetch
    https://github.com/vanstyn/RapidApp/commit/6f41f6e48 and
    http://lists.scsys.co.uk/pipermail/dbix-class/2015-February/011921.html
  - Fix hang in t/72pg.t when run against DBD::Pg 3.5.0. The ping()
    implementation changes due to RT#100648 made an alarm() based
    timeout lock-prone.
  * Misc
  - Remove warning about potential side effects of RT#79576 (scheduled)
  - Various doc improvements (GH#35, GH#62, GH#66, GH#70, GH#71, GH#72)
  - Depend on newer Moo, to benefit from a safer runtime (RT#93004)
  - Fix intermittent failures in the LeakTracer on 5.18+
  - Fix failures of t/54taint.t on Windows with spaces in the $^X
    executable path (RT#101615)
* Wed Nov 12 2014 coolo@suse.com
- updated to 0.082810
  * Fixes
  - Fix incorrect collapsing-parser source being generated in the
    presence of unicode data among the collapse-points
  - Fix endless loop on BareSourcelessResultClass->throw_exception(...)
  * Misc
  - Depend on newer SQL::Abstract (fixing overly-aggressive parenthesis
    opener: RT#99503)
  - Depend on newer Moo, fixing some interoperability issues:
    http://lists.scsys.co.uk/pipermail/dbix-class/2014-October/011787.html
  0.082801 2014-10-05 23:55 (UTC)
  * Known Issues
  - Passing large amounts of objects with stringification overload
    directly to DBIx::Class may result in strange action at a distance
    exceptions. More info (and a workaround description) can be found
    under "Note" at https://metacpan.org/pod/SQL::Abstract#is_plain_value
  - The relationship condition resolution fixes come with the side effect
    of returning more complete data, tripping up *some* users of an
    undocumented but widely used internal function. In particular
    https://rt.cpan.org/Ticket/Display.html?id=91375#txn-1407239
  * Notable Changes and Deprecations
  - DBIC::FilterColumn now properly bypasses \'' and \[] literals, just
    like the rest of DBIC
  - DBIC::FilterColumn "from_storage" handler is now invoked on NULLs
    returned from storage
  - find() now throws an exception if some of the supplied values are
    managed by DBIC::FilterColumn (RT#95054)
  - Custom condition relationships are now invoked with a slightly
    different signature (existing coderefs will continue to work)
  - Add extra custom condition coderef attribute 'foreign_values'
    to allow for proper reverse-relationship-like behavior
    (i.e. $result->set_from_related($custom_rel, $foreign_result_object)
  - When in a transaction, DBIC::Ordered now seamlesly handles result
    objects that went out of sync with the storage (RT#96499)
  - CDBICompat::columns() now supports adding columns through supplied
    Class::DBI::Column instances (GH#52)
  - Deprecate { col1 => col2 } expressions in manual {from} structures
    (at some point of time manual {from} will be deprecated entirely)
  * Fixes
  - Fix Resultset delete/update affecting *THE ENTIRE TABLE* in cases
    of empty (due to conditions) resultsets with multi-column keys
  - Fix on_connect_* not always firing in some cases - a race condition
    existed between storage accessor setters and the determine_driver
    routines, triggering a connection before the set-cycle is finished
  - Fix collapse being ignored on single-origin selection (RT#95658)
  - Fix incorrect behavior on custom result_class inflators altering
    the amount of returned results
  - Fix failure to detect stable order criteria when in iterator
    mode of a has_many prefetch off a search_related chain
  - Prevent erroneous database hit when accessing prefetched related
    resultsets with no rows
  - Proper exceptions on malformed relationship conditions (RT#92234)
  - Fix incorrect handling of custom relationship conditions returning
    SQLA literal expressions
  - Fix long standing bug with populate() missing data from hashrefs with
    different keysets: http://is.gd/2011_dbic_populate_gotcha (RT#92723)
  - Fix multi-value literal populate not working with simplified bind
    specifications
  - Massively improve the implied resultset condition parsing - now all
    applicable conditions within a resultset should be properly picked
    up by create() and populate()
  - Ensure definitive condition extractor handles bizarre corner cases
    without bombing out (RT#93244)
* Fri Mar  7 2014 coolo@suse.com
- updated to 0.08270
  * Fixes
  - Fix 0.08260 regression in DBD::SQLite bound int handling. Inserted
    data was not affected, but any function <=> integer comparison would
    have failed (originally fixed way back in 0e773352)
  - Fix failure to load DateTime formatter when connecting to Firebird
    over ODBC
  * Misc
  - All drivers based on ::Storage::DBI::Firebird::Common now return the
    same sqlt_type value (affects ::DBI::Interbase, ::DBI::Firebird and
    ::DBI::ODBC::Firebird)
  * New Features
  - A new zero-to-DBIC style manual: DBIx::Class::Manual::QuickStart
  * Notable Changes and Deprecations
  - Explicitly deprecate combination of distinct and selecting a
    non-column via $rs->get_column()
  * Fixes
  - More robust handling of circular relationship declarations by loading
    foreign classes less frequently (should resolve issues like
    http://lists.scsys.co.uk/pipermail/dbix-class/2013-June/011374.html)
    Note that none of this is a manifestations of a DBIC bug, but rather
    unexpected (but correct) behavior of load-order-dependent (hence
    logically broken) Resultclass hierarchies. In order to deal with this
    DBIC is scaling back a large number of sanity checks, which are to be
    reintroduce pending a better framework for source registration
  - Fix multiple edge cases of complex prefetch combining incorrectly
    with correlated subquery selections
  - Fix multiple edge cases stemming from interaction of a non-selecting
    order_by specification and distinct and/or complex prefetch
  - Fix unbound growth of a resultset during repeated execute/exhaust
    cycles (GH#29)
  - Work around (and be very vocal about the fact) when DBIC encounters
    an exception object with broken string overloading
  - Clarify ambiguous behavior of distinct when used with ResultSetColumn
    i.e. $rs->search({}, { distinct => 1 })->get_column (...)
  - Setting quote_names propagates to SQL::Translator when producing
    SQLite DDL (it is one of the few producers *NOT* quoting by default)
  - Fix incorrect binding of large integers on old versions of
    DBD::SQLite (now DBIC simply always binds SQLite ints as BIGINT)
  - Silence (harmless) warnings on recent DBD::SQLite versions, when
    inserting/updating large integers on 32bit ivsize systems (RT#76395)
  - Back out self-cleaning from DBIx::Class::Carp for the time being
    (as a side effect fixes RT#86267)
  - Fix incorrect internal use of implicit list context in copy()
  - Fix 0.08250 regression in driver determination when DBI_DSN is used
  - Tests no longer fail if $ENV{DBI_DSN} is set
  - Throw clearer exception on ->new_related() with a non-existent
    relationship
  - Fix incorrect parethesis unroll with multicolumn in, (never noticed
    before fixing false positive in SQLA::Test 1.77)
  - Fix t/storage/replicated.t class loading problem
  - Stop using the deprecated Class::MOP::load_class()
  - Fix warning in t/54taint.t with explicitly unset PERL5LIB (RT#91972)
  - Fix t/54taint.t failing under a local::lib with installed earlier
    DBIC version (RT#92486)
* Wed Jun 26 2013 coolo@suse.com
- updated to 0.08250
  * tons of changes, see Changes
* Mon Dec 12 2011 coolo@suse.com
- update to 0.08196
  * tons of changes, see Changes
* Thu Mar 31 2011 coolo@novell.com
- update to 0.08127
  * tons of changes, see Changes
- recreated by cpanspec 1.78.03
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Dec 11 2009 chris@computersalat.de
- make rpmlint happy
  * fix permissions
  * fix non unix files
* Fri Dec 11 2009 chris@computersalat.de
- update to 0.08115
  * see Changes file
- cleanup spec
  * added header
  * sorted Tags
  * fixed build-/deps
  * moved changelog to .changes
- added perl-macros
  * perl_gen_filelist
* Sun Oct 26 2008 gerrit.beine@gmx.de
- first release 0.08010
